summaryrefslogtreecommitdiff
path: root/numpy/_pyinstaller/hook-numpy.py
diff options
context:
space:
mode:
Diffstat (limited to 'numpy/_pyinstaller/hook-numpy.py')
-rw-r--r--numpy/_pyinstaller/hook-numpy.py7
1 files changed, 3 insertions, 4 deletions
diff --git a/numpy/_pyinstaller/hook-numpy.py b/numpy/_pyinstaller/hook-numpy.py
index 69992bdeb..6f24318ad 100644
--- a/numpy/_pyinstaller/hook-numpy.py
+++ b/numpy/_pyinstaller/hook-numpy.py
@@ -20,16 +20,15 @@ if is_pure_conda:
from PyInstaller.utils.hooks import conda_support
datas = conda_support.collect_dynamic_libs("numpy", dependencies=True)
-# Submodules PyInstaller cannot detect (probably because they are only imported
-# by extension modules, which PyInstaller cannot read).
-hiddenimports = ['numpy.core._dtype_ctypes']
+# Submodules PyInstaller cannot detect. `_dtype_ctypes` is only imported
+# from C and `_multiarray_tests` is used in tests (which are not packed).
+hiddenimports = ['numpy.core._dtype_ctypes', 'numpy.core._multiarray_tests']
# Remove testing and building code and packages that are referenced throughout
# NumPy but are not really dependencies.
excludedimports = [
"scipy",
"pytest",
- "nose",
"f2py",
"setuptools",
"numpy.f2py",